@@ -1443,6 +1443,10 @@ class LoadFormat(IntEnum):
     XLSB = 16,
     XLSX = 6,
     XML = 51,
+class LoadNumbersTableType(IntEnum):
+    ONE_TABLE_PER_SHEET = 1,
+    OVERRIDE_OTHER_TABLES = 2,
+    TILE_TABLES = 4,
 class LookAtType(IntEnum):
     CONTAINS = 0,
     END_WITH = 2,
@@ -2215,6 +2219,12 @@ class PresetShadowType(IntEnum):
     PERSPECTIVE_DIAGONAL_LOWER_RIGHT = 24,
     PERSPECTIVE_DIAGONAL_UPPER_LEFT = 20,
     PERSPECTIVE_DIAGONAL_UPPER_RIGHT = 21,
+class PresetThemeGradientType(IntEnum):
+    BOTTOM_SPOTLIGHT = 3,
+    LIGHT_GRADIENT = 0,
+    MEDIUM_GRADIENT = 2,
+    RADIAL_GRADIENT = 4,
+    TOP_SPOTLIGHT = 1,
 class PresetWordArtStyle(IntEnum):
     WORD_ART_STYLE_1 = 1,
     WORD_ART_STYLE_10 = 10,
@@ -3004,6 +3014,7 @@ from com.aspose.cells import MetadataOptions
 from com.aspose.cells import Metered
 from com.aspose.cells import MultipleFilterCollection
 from com.aspose.cells import NoneBulletValue
+from com.aspose.cells import NumbersLoadOptions
 from com.aspose.cells import OdsLoadOptions
 from com.aspose.cells import OdsPageBackground
 from com.aspose.cells import OdsSaveOptions
